@@ -23,7 +23,7 @@ class KMahjonggLayoutSelector : public QWidget, public Ui::KMahjonggLayoutSelect
     Q_OBJECT
 public:
     explicit KMahjonggLayoutSelector(QWidget * parent, KConfigSkeleton * config);
-    ~KMahjonggLayoutSelector();
+    ~KMahjonggLayoutSelector() override;
 
 public Q_SLOTS:
     void layoutChanged();
